<?php

namespace App\controleur;
use App\config\Validation;
use App\gateway\ImageManager;
use App\modele\MembreModele;

class MembreControleur extends UtilisateurControleur
{
    public function __construct()
    {}

    public function deconnexion()
    {
        session_unset();
        session_destroy();

        header("Location: /SAE_2A_FA-Reseau_ALICA/php/");
        exit();
    }
    
    public function createOfferForm()
    {
        global $twig;
        echo $twig->render("CreateOffer.html", []);
    }

    public function createOffer()
    {
        global $twig;
        $taberror = [];

        $requiredFields = ['name', 'entreprise', 'description','typeContrat', 'descriptPoste', 'profilRecherche', 'choixExp', 'education', 'mail', 'num'];

        $error = false;
        foreach ($requiredFields as $field) {
            if (empty($_POST[$field])) {
                $error = true;
                $taberror[] = "Le champ {$field} est requis !";
            }
        }
        if($error)
        {
            echo $twig->render("CreateOffer.html", ['tabError' => $taberror ]);
            return;
        }

        if(!Validation::verifierEmail($_POST["mail"]))
        {
            $taberror[] = "Email non valide !";
        }

        if(!Validation::validateNumber($_POST["num"]))
        {
            $taberror[] = "Numero non valide !";
        }

        if (!Validation::validateImage("image"))
        {
            $taberror[] = "Image non valide !";

        }
        if(!Validation::validateImage("logo")) {
            $taberror[] = "Logo non valide !";
        }

        if(count($taberror) > 0)
        {
            echo $twig->render("CreateOffer.html", ['tabError' => $taberror ]);

        }
        else{
            $saveImg1 = ImageManager::SaveImage("image");
            $saveImg2 = ImageManager::SaveImage("logo");
            if($saveImg1[0] != NULL &&  $saveImg2[0] != NULL)
            {
                $mbrModel = new MembreModele();

                $offre = $mbrModel->publishOffer($saveImg1[1], $saveImg2[1]);

                echo $twig->render("OffreDetailTest.html", ['offre' => $offre]);
            }
            else
            {
                $taberror[] = "Erreur lors de l'upload des images";
                echo $twig->render("CreateOffer.html", ['tabError' => $taberror ]);
            }
        }
    }


    public function deleteOffer(?array $params)
    {
        global $twig;
        $id = $params['id2'];

        $MemberModel = new MembreModele();
        $offre = $MemberModel->getOfferFromId($id);
        if($offre != NULL)
        {
            $MemberModel->deleteOffer($offre);

        }
        $this->consultOffers(null);

        /*$offre = $MemberModel->getOfferFromId($id);

        if($offre->getOffreur()->getId() == $_SESSION['id']
            || $_SESSION['role'] == "admin")
        {
            $MemberModel = new MembreModele();
            $MemberModel->deleteOffer($offre);
            $this->consultOffers();
        }*/

    }

    public function consulterProfil()
    {
        //TODO
    }

    public function modifierProfil()
    {
        //TODO
    }

    public function signaler()
    {
        //TODO
        echo "not implement yet";
    }

    public function displayProfil()
    {
        global $twig;
        $profilModel = new MembreModele();
        $profil = $profilModel->getFormationByProfil($_SESSION["id"]);
        var_dump($profil);
        if(isset($profil))
        {
            echo $twig->render("monProfil.html",['profil' => $profil]);
            return;
        } 
    }

    public function displayFormation()
    {
        global $twig;
        $formationModel = new MembreModele();
        $form = $formationModel->getFormationByProfil($_SESSION["id"]);
        var_dump($form);
        if(isset($form))
        {
            echo $twig->render("detailFormation.html",['formation' => $form]);
            return;
        } 
    }

    public function formationForm()
    {
        global $twig;
        echo $twig->render("creerFormation.html", []);
    }

    public function addFormation()
    {
        global $twig;

        if (!Validation::validerFormation($_SESSION["id"], $_POST["nom"], $_POST["ville"], $_POST["dateDeb"], $_POST["dateFin"], $_POST["currentFormation"])) {
            $modele = new MembreModele();
            $form = $modele->addExperience($_SESSION["id"], $_POST["nom"], $_POST["ville"], $_POST["dateDeb"], $_POST["dateFin"], $_POST["currentFormation"]);
            var_dump($form);
            $this->displayExperience($_SESSION["id"]);
            echo $twig->render('creerFormation.html', ['formation' => $form]);
        } else {
                $dVueErreur[] ="Erreur lors de la création de la formation";
                echo $twig->render("erreur.html",['dVueErreur' => $dVueErreur]);
        } 
    }

    public function deleteFormation(?array $params)
    {
        global $twing; 
        $mdl = new MembreModele();
        $mdl->deleteFormation($params['id2']);
        $this->displayFormation($_SESSION["id"]);
    }

    public function displayExperience()
    {
        global $twig;
        $experienceModel = new MembreModele();
        $exp = $experienceModel->getExperienceByProfil($_SESSION["id"]);
        //var_dump($exp);
        if(isset($exp))
        {
            echo $twig->render("detailExperience.html",['experience' => $exp]);
            return;
        } 
    }

    public function experienceForm()
    {
        global $twig;
        echo $twig->render("creerExperience.html", []);
    }

    public function addExperience()
    {
        global $twig;

        if (!Validation::validerExperience($_SESSION["id"], $_POST["intitule"], $_POST["dateDeb"], $_POST["dateFin"], $_POST["nomEntreprise"], $_POST["currentJob"])) {
            $modele = new MembreModele();
            $exp = $modele->addExperience($_SESSION["id"], $_POST["intitule"], $_POST["dateDeb"], $_POST["dateFin"], $_POST["nomEntreprise"], $_POST["currentJob"]);
            var_dump($exp);
            $this->displayExperience($_SESSION["id"]);
            echo $twig->render('creerExperience.html', ['experience' => $exp]);
        } else {
                $dVueErreur[] ="Erreur lors de la création de l'évènement";
                echo $twig->render("erreur.html",['dVueErreur' => $dVueErreur]);
        } 
    }


    public function deleteExperience(?array $params)
    {
        global $twing; 
        $mdl = new MembreModele();
        $mdl->deleteExperience($params['id2']);
        $this->displayExperience($_SESSION["id"]);
    }
}


